﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="OxyKey.cs" company="OxyPlot">
//   Copyright (c) 2014 OxyPlot contributors
// </copyright>
// <summary>
//   Defines the possible key values on a keyboard.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace OxyPlot
{
    /// <summary>
    /// Defines the possible key values on a keyboard.
    /// </summary>
    public enum OxyKey
    {
        /// <summary>
        /// The Space key.
        /// </summary>
        Space,

        /// <summary>
        /// The Enter key.
        /// </summary>
        Enter,

        /// <summary>
        /// The Esc key.
        /// </summary>
        Escape,

        /// <summary>
        /// The Tab key.
        /// </summary>
        Tab,

        /// <summary>
        /// The Backspace key.
        /// </summary>
        Backspace,

        /// <summary>
        /// The Insert key.
        /// </summary>
        Insert,

        /// <summary>
        /// The Delete key.
        /// </summary>
        Delete,

        /// <summary>
        /// The Home key.
        /// </summary>
        Home,

        /// <summary>
        /// The End key.
        /// </summary>
        End,

        /// <summary>
        /// The Up arrow key.
        /// </summary>
        Up,

        /// <summary>
        /// The Down arrow key.
        /// </summary>
        Down,

        /// <summary>
        /// The Left arrow key.
        /// </summary>
        Left,

        /// <summary>
        /// The Right arrow key.
        /// </summary>
        Right,

        /// <summary>
        /// The Page up key.
        /// </summary>
        PageUp,

        /// <summary>
        /// The Page down key.
        /// </summary>
        PageDown,

        /// <summary>
        /// The A key.
        /// </summary>
        A,

        /// <summary>
        /// The B key.
        /// </summary>
        B,

        /// <summary>
        /// The C key.
        /// </summary>
        C,

        /// <summary>
        /// The D key.
        /// </summary>
        D,

        /// <summary>
        /// The E key.
        /// </summary>
        E,

        /// <summary>
        /// The F key.
        /// </summary>
        F,

        /// <summary>
        /// The G key.
        /// </summary>
        G,

        /// <summary>
        /// The H key.
        /// </summary>
        H,

        /// <summary>
        /// The I key.
        /// </summary>
        I,

        /// <summary>
        /// The J key.
        /// </summary>
        J,

        /// <summary>
        /// The K key.
        /// </summary>
        K,

        /// <summary>
        /// The L key.
        /// </summary>
        L,

        /// <summary>
        /// The M key.
        /// </summary>
        M,

        /// <summary>
        /// The N key.
        /// </summary>
        N,

        /// <summary>
        /// The O key.
        /// </summary>
        O,

        /// <summary>
        /// The P key.
        /// </summary>
        P,

        /// <summary>
        /// The Q key.
        /// </summary>
        Q,

        /// <summary>
        /// The R key.
        /// </summary>
        R,

        /// <summary>
        /// The S key.
        /// </summary>
        S,

        /// <summary>
        /// The T key.
        /// </summary>
        T,

        /// <summary>
        /// The U key.
        /// </summary>
        U,

        /// <summary>
        /// The V key.
        /// </summary>
        V,

        /// <summary>
        /// The W key.
        /// </summary>
        W,

        /// <summary>
        /// The X key.
        /// </summary>
        X,

        /// <summary>
        /// The Y key.
        /// </summary>
        Y,

        /// <summary>
        /// The Z key.
        /// </summary>
        Z,

        /// <summary>
        /// The 0 key.
        /// </summary>
        D0,

        /// <summary>
        /// The 1 key.
        /// </summary>
        D1,

        /// <summary>
        /// The 2 key.
        /// </summary>
        D2,

        /// <summary>
        /// The 3 key.
        /// </summary>
        D3,

        /// <summary>
        /// The 4 key.
        /// </summary>
        D4,

        /// <summary>
        /// The 5 key.
        /// </summary>
        D5,

        /// <summary>
        /// The 6 key.
        /// </summary>
        D6,

        /// <summary>
        /// The 7 key.
        /// </summary>
        D7,

        /// <summary>
        /// The 8 key.
        /// </summary>
        D8,

        /// <summary>
        /// The 9 key.
        /// </summary>
        D9,

        /// <summary>
        /// The 0 key on the numeric keypad.
        /// </summary>
        NumPad0,

        /// <summary>
        /// The 1 key on the numeric keypad.
        /// </summary>
        NumPad1,

        /// <summary>
        /// The 2 key on the numeric keypad.
        /// </summary>
        NumPad2,

        /// <summary>
        /// The 3 key on the numeric keypad.
        /// </summary>
        NumPad3,

        /// <summary>
        /// The 4 key on the numeric keypad.
        /// </summary>
        NumPad4,

        /// <summary>
        /// The 5 key on the numeric keypad.
        /// </summary>
        NumPad5,

        /// <summary>
        /// The 6 key on the numeric keypad.
        /// </summary>
        NumPad6,

        /// <summary>
        /// The 7 key on the numeric keypad.
        /// </summary>
        NumPad7,

        /// <summary>
        /// The 8 key on the numeric keypad.
        /// </summary>
        NumPad8,

        /// <summary>
        /// The 9 key on the numeric keypad.
        /// </summary>
        NumPad9,

        /// <summary>
        /// The add key.
        /// </summary>
        Add,

        /// <summary>
        /// The subtract key.
        /// </summary>
        Subtract,

        /// <summary>
        /// The multiply key.
        /// </summary>
        Multiply,

        /// <summary>
        /// The divide key.
        /// </summary>
        Divide,

        /// <summary>
        /// The decimal key.
        /// </summary>
        Decimal,

        /// <summary>
        /// The F1 key.
        /// </summary>
        F1,

        /// <summary>
        /// The F2 key.
        /// </summary>
        F2,

        /// <summary>
        /// The F3 key.
        /// </summary>
        F3,

        /// <summary>
        /// The F4 key.
        /// </summary>
        F4,

        /// <summary>
        /// The F5 key.
        /// </summary>
        F5,

        /// <summary>
        /// The F6 key.
        /// </summary>
        F6,

        /// <summary>
        /// The F7 key.
        /// </summary>
        F7,

        /// <summary>
        /// The F8 key.
        /// </summary>
        F8,

        /// <summary>
        /// The F9 key.
        /// </summary>
        F9,

        /// <summary>
        /// The F10 key.
        /// </summary>
        F10,

        /// <summary>
        /// The F11 key.
        /// </summary>
        F11,

        /// <summary>
        /// The F12 key.
        /// </summary>
        F12,

        /// <summary>
        /// Unknown/not supported key.
        /// </summary>
        Unknown
    }
}